@@ -1,6 +1,6 @@
 package LWP;
 
-our $VERSION = '6.57';
+our $VERSION = '6.58';
 
 require LWP::UserAgent;  # this should load everything you need
 
@@ -103,7 +103,7 @@ The libwww-perl library is based on HTTP style communication. This
 section tries to describe what that means.
 
 Let us start with this quote from the HTTP specification document
-<URL:http://www.w3.org/Protocols/>:
+L<http://www.w3.org/Protocols/>:
 
 =over 3
 
@@ -273,12 +273,12 @@ address will be sent to the servers with every request.
 =item *
 
 B<parse_head> specifies whether we should initialize response
-headers from the E<lt>head> section of HTML documents.
+headers from the C<< <head> >> section of HTML documents.
 
 =item *
 
 B<proxy> and B<no_proxy> specify if and when to go through
-a proxy server. <URL:http://www.w3.org/History/1994/WWW/Proxies/>
+a proxy server. L<http://www.w3.org/History/1994/WWW/Proxies/>
 
 =item *
 
@@ -318,7 +318,7 @@ represented in actual perl code:
       print $res->status_line, "\n";
   }
 
-The $ua is created once when the application starts up.  New request
+The C<$ua> is created once when the application starts up.  New request
 objects should normally created for each request sent.
 
 
@@ -328,7 +328,7 @@ This section discusses the various protocol schemes and
 the HTTP style methods that headers may be used for each.
 
 For all requests, a "User-Agent" header is added and initialized from
-the $ua->agent attribute before the request is handed to the network
+the C<< $ua->agent >> attribute before the request is handed to the network
 layer.  In the same way, a "From" header is initialized from the
 $ua->from attribute.
 
