@@ -1,9 +1,9 @@
 package LWP::Authen::Digest;
 
 use strict;
-use base 'LWP::Authen::Basic';
+use parent 'LWP::Authen::Basic';
 
-our $VERSION = '6.57';
+our $VERSION = '6.58';
 
 require Digest::MD5;
 
