@@ -9,9 +9,9 @@ package LWP::Debug::TraceHTTP;
 # programs that use LWP.
 
 use strict;
-use base 'LWP::Protocol::http';
+use parent 'LWP::Protocol::http';
 
-our $VERSION = '6.57';
+our $VERSION = '6.58';
 
 package # hide from PAUSE
     LWP::Debug::TraceHTTP::Socket;
