@@ -2,9 +2,9 @@ package LWP::Protocol::nntp;
 
 # Implementation of the Network News Transfer Protocol (RFC 977)
 
-use base qw(LWP::Protocol);
+use parent qw(LWP::Protocol);
 
-our $VERSION = '6.57';
+our $VERSION = '6.58';
 
 require HTTP::Response;
 require HTTP::Status;
